/* name:    metaDataInfosMacro.rex
   author:  Rony G. Flatscher
   date:    2008-06-18
   purpose: query and display the script/macro's meta data
*/
signal on syntax /* uncomment, if condition/exceptions should be displayed in a popup dialog */

scriptContext=uno.getScriptContext()         /* get the xScriptContext object                   */
oDoc=scriptContext~getDocument               /* get the document service (a XModel) object      */
/*
xDesktop=scriptContext~getDesktop            /* get the desktop (a XDesktop) object             */
*/
xContext=scriptContext~getComponentContext   /* get the context (a XComponentContext) object    */

      /* demonstration of how to interact with different document types */
str="Hello world ["date("s") time()"] by http://www.ooRexx.org! "    /* define some text        */

metaData=uno.getScriptMetaData()             /* get the script's metadata                       */
methods="getClassPath getDescription getLanguage getLanguageName getLanguageProperties" -
        "getLocation getLogicalName getLocationPlaceHolder getParcelLocation"           -
        "getScriptFullURL  getShortFormScriptURL loadSource hasSource getSource"        -
        "getSourceBytes getSourceURL"

methods=methods~space~makearray(" ")         /* turn string into an array                    */

LF="0a"x                                  /* LF (line-feed) character (soft paragraph)       */
CR="0d"x                                  /* CR (carriage-return character (paragraph)       */
TAB="09"x
.local~maxLength=200                      /* maximum of 200 chars of result                  */

if oDoc~uno.queryServiceName("TextDocument")<>"" then    /* a TextDcoument in hand?             */
do
   xTextDoc=oDoc~XTextDocument               /* get the XTextDocument interface                 */
   xTextDoc~getText~getEnd~setString(str)    /* add text at the end of the text document        */

   xTextDoc~getText~getEnd~setString(LF LF) /* add text at the end of the text document        */
   do i=1 to methods~items
      methodName=methods[i]
      xTextDoc~getText~getEnd~setString(methodName":"TAB) /* add text at the end of the text document        */
      xTextDoc~getText~getEnd~setString(pp(getValue(metaData,methodName)) || LF) /* add text at the end of the text document        */
   end
   xTextDoc~getText~getEnd~setString(CR || CR)
end

else if oDoc~uno.queryServiceName("SpreadsheetDocument")<>"" then /* a SpreadsheetDocument?     */
do
   xSheet = oDoc~XSpreadSheetDocument~getSheets~XIndexAccess~getByIndex(0)~XSpreadSheet
   call uno.setCell xSheet, "A1", str        /* set the text in the cell                        */

   do i=1 to methods~items
      line=i+2
      methodName=methods[i]

      call uno.setCell xSheet, "A"line, methodName
      call uno.setCell xSheet, "B"line, pp(getValue(metaData,methodName))
   end
end

else  /* an unknown document type, display its implemented service(s)   */
do
   TAB="    "
   parse source s
   tmpStr=str LF LF || s LF LF

   title="Unknown Document Type Implementing the Following Service(s)"
   url=oDoc~getUrl                           /* get Document's name (an URL)                    */


   if url<>"" then tmpStr=tmpStr "Document URL/Name:" pp(url)

   tmpStr=tmpStr LF || "List of implemented services:"  -
                 LF || (" "oDoc~uno.getServiceNames)~changestr(" ", LF || TAB "- ") LF

   tmpStr=tmpStr LF || "Information from script/macro meta data object:" LF LF

   do i=1 to methods~items
      methodName=methods[i]
      tmpStr=tmpStr  TAB  "- "|| methodName":" || pp(getValue(metaData,methodName)) || LF
   end

   .bsf.dialog~messageBox(tmpStr, title, "information")
end
      /* <== replace the previous part with your code (end)   */
return


/* this is a sample of how one could exploit ooRexx and BSF4Rexx error information */
syntax:    /* create and display condition/exception information in a popup dialog */
   o=condition("O")     -- get condition object, describing the condition/exception
   LF="0a"x             -- the line-feed character
   TAB="        "       -- blanks simulating a tab character

   tmpStr=""            -- set to empty string
   do idx over o~makeArray~sort   /* sort the directory indexes and iterate over them */
      val=o[idx]        -- get the associated value from the condition object (a directory)
      tmpStr=tmpStr || (idx || ":")~left(25) pp(val) LF

      if val~hasmethod("items") then   -- a collection? show its content
      do item over val
         tmpStr=tmpStr || tab || tab || pp(item) || LF
      end
   end

   if length(tmpStr)>750 then tmpStr=left(tmpStr,750)"..." -- show only the first 750 chars

   /* Are there any Java error messages/stack traces available, if so, show them */
   if var("BSF_ERROR_MESSAGE") | .local~hasEntry("BSF_ERROR_MESSAGE") then -- a BSF error message ?
   do
      if var("BSF_ERROR_MESSAGE") then errStr=BSF_ERROR_MESSAGE   -- variable from this scope
                                  else errStr=.bsf_error_message  -- value from .local environment

      tmpStr=tmpStr LF LF || "-"~copies(80) LF   -- extend the string
      tmpStr=tmpStr          "*** BSF4Rexx Error Information: ***" LF LF
      if length(errStr)>1000 then
         tmpStr=tmpStr || left(errStr,1000)"..."
      else
         tmpStr=tmpStr || errStr
   end

   .bsf.dialog~messageBox(tmpStr, "Runtime error #" o~code, "error") -- display the string


::requires UNO.CLS   /* load UNO support (OpenOffice/StarOffice) for ooRexx   */

::routine getValue
  use arg metaData, methodName

  signal on syntax
      -- send message, retrieve value
  val=.message~new(metaData,methodName)~send
  if val~isA(.BSF) then val=val~toString

      -- make sure not too long
  if length(val)>.maxLength then
     val=val~left(.maxLength)"..."

  return val

   /* save value of BSF_ERROR_MESSAGE in .local, otherwise we have no access in caller! */
syntax:                 -- intercept exception
  raise propagate       -- now raise exception in caller


